@@ -4,7 +4,7 @@
  * control the pace of reading. 
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: input_ext-intf.h,v 1.51.2.1 2001/12/31 01:21:44 massiot Exp $
+ * $Id: input_ext-intf.h,v 1.63 2002/03/21 02:27:04 jobi Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -34,15 +34,33 @@
 
 #define OFFSETTOTIME_MAX_SIZE       10
 
+/*****************************************************************************
+ * input_bank_t, p_input_bank (global variable)
+ *****************************************************************************
+ * This global variable is accessed by any function using the input.
+ *****************************************************************************/
+typedef struct input_bank_s
+{
+    /* Array to all the input threads */
+    struct input_thread_s *pp_input[ INPUT_MAX_THREADS ];
+
+    int                   i_count;
+    vlc_mutex_t           lock;                               /* Global lock */
+
+} input_bank_t;
+
+#ifndef PLUGIN
+extern input_bank_t *p_input_bank;
+#else
+#   define p_input_bank (p_symbols->p_input_bank)
+#endif
+
 /*****************************************************************************
  * es_descriptor_t: elementary stream descriptor
  *****************************************************************************
  * Describes an elementary stream, and includes fields required to handle and
  * demultiplex this elementary stream.
  *****************************************************************************/
-struct decoder_fifo_s;                         /* defined in input_ext-dec.h */
-struct pgrm_descriptor_s;
-
 typedef struct es_descriptor_s
 {
     u16                     i_id;            /* stream ID for PS, PID for TS */
@@ -53,7 +71,10 @@ typedef struct es_descriptor_s
                                            * fast forward and slow motion ?  */
     u8                      i_cat;        /* stream category: video, audio,
                                            * spu, other */
-
+#ifdef HAVE_SATELLITE
+    int                     i_dmx_fd;     /* used to store demux device
+                                             file handle */
+#endif
     char                    psz_desc[20]; /* description of ES: audio language
                                            * for instance ; NULL if not
                                            *  available */
@@ -156,8 +177,6 @@ typedef struct input_area_s
     int                     i_part_nb;   /* number of parts (chapter for DVD)*/
     int                     i_part;      /* currently selected part */
 
-    int                     i_angle_nb;  /* number of angles/title units */
-    int                     i_angle;
 
     /* offset to plugin related data */
     off_t                   i_plugin_data;
@@ -234,9 +253,6 @@ typedef struct stream_descriptor_s
  *****************************************************************************
  * This structure includes all the local static variables of an input thread
  *****************************************************************************/
-struct vout_thread_s;
-struct bit_stream_s;
-
 typedef struct input_thread_s
 {
     /* Thread properties and locks */
@@ -244,55 +260,47 @@ typedef struct input_thread_s
     boolean_t               b_error;
     boolean_t               b_eof;
     vlc_thread_t            thread_id;            /* id for thread functions */
-    int *                   pi_status;              /* temporary status flag */
+    int                     i_status;                         /* status flag */
 
-    /* Input module */
-    struct module_s *       p_input_module;
-
-    /* Init/End */
-    void                 (* pf_init)( struct input_thread_s * );
-    void                 (* pf_open)( struct input_thread_s * );
+    /* Access module */
+    struct module_s *       p_access_module;
+    int                  (* pf_open)( struct input_thread_s * );
     void                 (* pf_close)( struct input_thread_s * );
-    void                 (* pf_end)( struct input_thread_s * );
-    void                 (* pf_init_bit_stream)( struct bit_stream_s *,
-                              struct decoder_fifo_s *,
-                void (* pf_bitstream_callback)( struct bit_stream_s *,
-                                                boolean_t ),
-                              void * );
-
-    /* Read & Demultiplex */
-    int                  (* pf_read)( struct input_thread_s *,
-                                      struct data_packet_s ** );
-    void                 (* pf_demux)( struct input_thread_s *,
-                                       struct data_packet_s * );
-
-    /* Packet management facilities */
-    struct data_packet_s *(*pf_new_packet)( void *, size_t );
-    struct pes_packet_s *(* pf_new_pes)( void * );
-    void                 (* pf_delete_packet)( void *,
-                                               struct data_packet_s * );
-    void                 (* pf_delete_pes)( void *, struct pes_packet_s * );
-
-    /* Stream control capabilities */
+    ssize_t              (* pf_read) ( struct input_thread_s *,
+                                       byte_t *, size_t );
     int                  (* pf_set_program)( struct input_thread_s *,
                                              struct pgrm_descriptor_s * );
     int                  (* pf_set_area)( struct input_thread_s *,
                                           struct input_area_s * );
+    void                 (* pf_seek)( struct input_thread_s *, off_t );
+    void *                  p_access_data;
+    size_t                  i_mtu;
+
+    /* Demux module */
+    struct module_s *       p_demux_module;
+    int                  (* pf_init)( struct input_thread_s * );
+    void                 (* pf_end)( struct input_thread_s * );
+    int                  (* pf_demux)( struct input_thread_s * );
     int                  (* pf_rewind)( struct input_thread_s * );
                                            /* NULL if we don't support going *
                                             * backwards (it's gonna be fun)  */
-    void                 (* pf_seek)( struct input_thread_s *, off_t );
+    void *                  p_demux_data;               /* data of the demux */
 
-    char *                  p_source;
-
-    int                     i_handle;           /* socket or file descriptor */
-    FILE *                  p_stream;                       /* if applicable */
-    void *                  p_handle;          /* if i_handle isn't suitable */
-    void *                  p_method_data;     /* data of the packet manager */
-    void *                  p_plugin_data;             /* data of the plugin */
+    /* Buffer manager */
+    struct input_buffers_s *p_method_data;     /* data of the packet manager */
+    struct data_buffer_s *  p_data_buffer;
+    byte_t *                p_current_data;
+    byte_t *                p_last_data;
+    size_t                  i_bufsize;
 
     /* General stream description */
-    stream_descriptor_t     stream;                            /* PAT tables */
+    stream_descriptor_t     stream;
+
+    /* Playlist item */
+    char *                  psz_source;
+    char *                  psz_access;
+    char *                  psz_demux;
+    char *                  psz_name;
 
     count_t                 c_loops;
 } input_thread_t;
@@ -310,7 +318,8 @@ typedef struct input_thread_s
 #define INPUT_METHOD_MCAST       0x32                       /* UDP multicast */
 #define INPUT_METHOD_BCAST       0x33                       /* UDP broadcast */
 #define INPUT_METHOD_VLAN_BCAST  0x34            /* UDP broadcast with VLANs */
-
+#define INPUT_METHOD_SATELLITE   0x40               /* stream is read from a */
+                                                           /* satellite card */
 
 /* Status changing methods */
 #define INPUT_STATUS_END            0
@@ -323,20 +332,35 @@ typedef struct input_thread_s
  * Prototypes
  *****************************************************************************/
 #ifndef PLUGIN
+void   input_InitBank       ( void );
+void   input_EndBank        ( void );
+
 struct input_thread_s * input_CreateThread ( struct playlist_item_s *,
                                              int *pi_status );
-void input_DestroyThread( struct input_thread_s *, int *pi_status );
+void   input_StopThread     ( struct input_thread_s *, int *pi_status );
+void   input_DestroyThread  ( struct input_thread_s * );
 
-void input_SetStatus( struct input_thread_s *, int );
-void input_Seek     ( struct input_thread_s *, off_t );
-void input_DumpStream( struct input_thread_s * );
-char * input_OffsetToTime( struct input_thread_s *, char * psz_buffer, off_t );
-int  input_ChangeES ( struct input_thread_s *, struct es_descriptor_s *, u8 );
-int  input_ToggleES ( struct input_thread_s *,
-                      struct es_descriptor_s *,
-                      boolean_t );
-int  input_ChangeArea( struct input_thread_s *, struct input_area_s * );
-int  input_ToggleGrayscale( struct input_thread_s * );
-int  input_ToggleMute( struct input_thread_s * );
-int  input_SetSMP( struct input_thread_s *, int );
+void   input_SetStatus      ( struct input_thread_s *, int );
+void   input_Seek           ( struct input_thread_s *, off_t );
+void   input_DumpStream     ( struct input_thread_s * );
+char * input_OffsetToTime   ( struct input_thread_s *, char *, off_t );
+int    input_ChangeES       ( struct input_thread_s *,
+                              struct es_descriptor_s *, u8 );
+int    input_ToggleES       ( struct input_thread_s *,
+                              struct es_descriptor_s *, boolean_t );
+int    input_ChangeArea     ( struct input_thread_s *, struct input_area_s * );
+int    input_ChangeProgram  ( struct input_thread_s *, u16 );
+int    input_ToggleGrayscale( struct input_thread_s * );
+int    input_ToggleMute     ( struct input_thread_s * );
+int    input_SetSMP         ( struct input_thread_s *, int );
+#else
+#   define input_SetStatus      p_symbols->input_SetStatus
+#   define input_Seek           p_symbols->input_Seek
+#   define input_DumpStream     p_symbols->input_DumpStream
+#   define input_OffsetToTime   p_symbols->input_OffsetToTime
+#   define input_ChangeES       p_symbols->input_ChangeES
+#   define input_ToggleES       p_symbols->input_ToggleES
+#   define input_ChangeArea     p_symbols->input_ChangeArea
+#   define input_ChangeProgram  p_symbols->input_ChangeProgram
 #endif
+
