@@ -2,7 +2,7 @@
  * downmix.c : AC3 downmix module
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: downmix.c,v 1.4 2001/11/28 15:08:05 massiot Exp $
+ * $Id: downmix.c,v 1.7 2002/02/15 13:32:53 sam Exp $
  *
  * Authors: Renaud Dartus <reno@via.ecp.fr>
  *
@@ -21,48 +21,33 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-#define MODULE_NAME downmix
-#include "modules_inner.h"
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <stdlib.h>
 #include <string.h>
 
-#include "config.h"
-#include "common.h"
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
-#include "tests.h"
+#include <videolan/vlc.h>
 
 #include "ac3_downmix.h"
 #include "ac3_downmix_common.h"
 
-#include "modules.h"
-#include "modules_export.h"
-
 /*****************************************************************************
  * Local and extern prototypes.
  *****************************************************************************/
 static void downmix_getfunctions( function_list_t * p_function_list );
-static int  downmix_Probe       ( probedata_t *p_data );
 
 /*****************************************************************************
  * Build configuration tree.
  *****************************************************************************/
 MODULE_CONFIG_START
-ADD_WINDOW( "Configuration for AC3 downmix module" )
-    ADD_COMMENT( "Ha, ha -- nothing to configure yet" )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    p_module->i_capabilities = MODULE_CAPABILITY_NULL
-                                | MODULE_CAPABILITY_DOWNMIX;
-    p_module->psz_longname = "AC3 downmix module";
+    SET_DESCRIPTION( "AC3 downmix module" )
+    ADD_CAPABILITY( DOWNMIX, 50 )
+    ADD_SHORTCUT( "c" )
+    ADD_SHORTCUT( "downmix" )
 MODULE_INIT_STOP
 
 MODULE_ACTIVATE_START
@@ -80,7 +65,6 @@ MODULE_DEACTIVATE_STOP
  *****************************************************************************/
 static void downmix_getfunctions( function_list_t * p_function_list )
 {
-    p_function_list->pf_probe = downmix_Probe;
 #define F p_function_list->functions.downmix
     F.pf_downmix_3f_2r_to_2ch = _M( downmix_3f_2r_to_2ch );
     F.pf_downmix_3f_1r_to_2ch = _M( downmix_3f_1r_to_2ch );
@@ -92,18 +76,3 @@ static void downmix_getfunctions( function_list_t * p_function_list )
 #undef F
 }
 
-/*****************************************************************************
- * downmix_Probe: returns a preference score
- *****************************************************************************/
-static int downmix_Probe( probedata_t *p_data )
-{
-    if( TestMethod( DOWNMIX_METHOD_VAR, "downmix" )
-         || TestMethod( DOWNMIX_METHOD_VAR, "c" ) )
-    {
-        return( 999 );
-    }
-
-    /* This plugin always works */
-    return( 50 );
-}
-
