@@ -2,7 +2,7 @@
  * dsp.c : OSS /dev/dsp module for vlc
  *****************************************************************************
  * Copyright (C) 2000-2001 VideoLAN
- * $Id: dsp.c,v 1.10 2001/11/28 15:08:05 massiot Exp $
+ * $Id: dsp.c,v 1.14 2002/02/27 18:19:21 sam Exp $
  *
  * Authors: Michel Kaempf <maxx@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -22,25 +22,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-#define MODULE_NAME dsp
-#include "modules_inner.h"
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <stdlib.h>                                      /* malloc(), free() */
 #include <string.h>                                              /* strdup() */
 
-#include "config.h"
-#include "common.h"                                     /* boolean_t, byte_t */
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
-
-#include "modules.h"
-#include "modules_export.h"
+#include <videolan/vlc.h>
 
 /*****************************************************************************
  * Capabilities defined in the other files.
@@ -51,15 +39,14 @@ void _M( aout_getfunctions )( function_list_t * p_function_list );
  * Build configuration tree.
  *****************************************************************************/
 MODULE_CONFIG_START
-ADD_WINDOW( "Configuration for dsp module" )
-    ADD_FRAME( "OSS Device" )
-        ADD_FILE( "Device name: ", MODULE_VAR(device), NULL )
+ADD_CATEGORY_HINT( "Misc Options", NULL )
+ADD_FILE  ( "dsp_dev", "/dev/dsp", NULL,"OSS dsp device",NULL )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    p_module->i_capabilities = MODULE_CAPABILITY_NULL
-                                | MODULE_CAPABILITY_AOUT;
-    p_module->psz_longname = "Linux OSS /dev/dsp module";
+    SET_DESCRIPTION( "Linux OSS /dev/dsp module" )
+    ADD_CAPABILITY( AOUT, 100 )
+    ADD_SHORTCUT( "dsp" )
 MODULE_INIT_STOP
 
 MODULE_ACTIVATE_START
