@@ -2,7 +2,7 @@
  * vout_dummy.c: Dummy video output display method for testing purposes
  *****************************************************************************
  * Copyright (C) 2000, 2001 VideoLAN
- * $Id: vout_dummy.c,v 1.9 2001/11/28 15:08:05 massiot Exp $
+ * $Id: vout_dummy.c,v 1.21 2002/04/05 01:05:22 gbazin Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -21,35 +21,21 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-#define MODULE_NAME dummy
-#include "modules_inner.h"
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <errno.h>                                                 /* ENOMEM */
 #include <stdlib.h>                                                /* free() */
 #include <string.h>                                            /* strerror() */
 
-#include "config.h"
-#include "common.h"
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
-#include "tests.h"
+#include <videolan/vlc.h>
 
 #include "video.h"
 #include "video_output.h"
 
-#include "modules.h"
-#include "modules_export.h"
-
 #define DUMMY_WIDTH 16
 #define DUMMY_HEIGHT 16
-#define DUMMY_BITS_PER_PLANE 16
-#define DUMMY_BYTES_PER_PIXEL 2
+#define DUMMY_MAX_DIRECTBUFFERS 10
 
 /*****************************************************************************
  * vout_sys_t: dummy video output method descriptor
@@ -59,22 +45,25 @@
  *****************************************************************************/
 typedef struct vout_sys_s
 {
-    /* Dummy video memory */
-    byte_t *                    p_video;                      /* base adress */
-    size_t                      i_page_size;                    /* page size */
+    /* Nothing needed here. Maybe stats ? */
+
+    /* Prevent malloc(0) */
+    int i_dummy;
 
 } vout_sys_t;
 
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
-static int  vout_Probe     ( probedata_t *p_data );
 static int  vout_Create    ( struct vout_thread_s * );
 static int  vout_Init      ( struct vout_thread_s * );
 static void vout_End       ( struct vout_thread_s * );
 static void vout_Destroy   ( struct vout_thread_s * );
 static int  vout_Manage    ( struct vout_thread_s * );
-static void vout_Display   ( struct vout_thread_s * );
+static void vout_Render    ( struct vout_thread_s *, struct picture_s * );
+static void vout_Display   ( struct vout_thread_s *, struct picture_s * );
+
+static int  DummyNewPicture( struct vout_thread_s *, struct picture_s * );
 
 /*****************************************************************************
  * Functions exported as capabilities. They are declared as static so that
@@ -82,27 +71,13 @@ static void vout_Display   ( struct vout_thread_s * );
  *****************************************************************************/
 void _M( vout_getfunctions )( function_list_t * p_function_list )
 {
-    p_function_list->pf_probe = vout_Probe;
     p_function_list->functions.vout.pf_create     = vout_Create;
     p_function_list->functions.vout.pf_init       = vout_Init;
     p_function_list->functions.vout.pf_end        = vout_End;
     p_function_list->functions.vout.pf_destroy    = vout_Destroy;
     p_function_list->functions.vout.pf_manage     = vout_Manage;
+    p_function_list->functions.vout.pf_render     = vout_Render;
     p_function_list->functions.vout.pf_display    = vout_Display;
-    p_function_list->functions.vout.pf_setpalette = NULL;
-}
-
-/*****************************************************************************
- * intf_Probe: return a score
- *****************************************************************************/
-static int vout_Probe( probedata_t *p_data )
-{
-    if( TestMethod( VOUT_METHOD_VAR, "dummy" ) )
-    {
-        return( 999 );
-    }
-
-    return( 1 );
 }
 
 /*****************************************************************************
@@ -120,29 +95,6 @@ static int vout_Create( vout_thread_t *p_vout )
         return( 1 );
     }
 
-    p_vout->i_width            = DUMMY_WIDTH;
-    p_vout->i_height           = DUMMY_HEIGHT;
-    p_vout->i_screen_depth     = DUMMY_BITS_PER_PLANE;
-    p_vout->i_bytes_per_pixel  = DUMMY_BYTES_PER_PIXEL;
-    p_vout->i_bytes_per_line   = DUMMY_WIDTH * DUMMY_BYTES_PER_PIXEL;
-
-    p_vout->p_sys->i_page_size = DUMMY_WIDTH * DUMMY_HEIGHT
-                                  * DUMMY_BYTES_PER_PIXEL;
-
-    /* Map two framebuffers a the very beginning of the fb */
-    p_vout->p_sys->p_video = malloc( 2 * p_vout->p_sys->i_page_size );
-    if( p_vout->p_sys->p_video == NULL )
-    {
-        intf_ErrMsg( "vout error: can't map video memory (%s)",
-                     strerror(errno) );
-        free( p_vout->p_sys );
-        return( 1 );
-    }
-
-    /* Set and initialize buffers */
-    p_vout->pf_setbuffers( p_vout, p_vout->p_sys->p_video,
-                     p_vout->p_sys->p_video + p_vout->p_sys->i_page_size );
-
     return( 0 );
 }
 
@@ -151,6 +103,63 @@ static int vout_Create( vout_thread_t *p_vout )
  *****************************************************************************/
 static int vout_Init( vout_thread_t *p_vout )
 {
+    int i_index;
+    picture_t *p_pic;
+    
+    I_OUTPUTPICTURES = 0;
+
+    /* Initialize the output structure */
+    switch( p_vout->render.i_chroma )
+    {
+        case FOURCC_I420:
+        case FOURCC_IYUV:
+        case FOURCC_YV12:
+            p_vout->output.i_chroma = p_vout->render.i_chroma;
+            p_vout->output.i_width  = p_vout->render.i_width;
+            p_vout->output.i_height = p_vout->render.i_height;
+            p_vout->output.i_aspect = p_vout->render.i_aspect;
+            break;
+
+        default:
+            p_vout->output.i_chroma = FOURCC_RV16;
+            p_vout->output.i_rmask  = 0xf800;
+            p_vout->output.i_gmask  = 0x07e0;
+            p_vout->output.i_bmask  = 0x001f;
+            p_vout->output.i_width  = p_vout->render.i_width;
+            p_vout->output.i_height = p_vout->render.i_height;
+            p_vout->output.i_aspect = p_vout->render.i_aspect;
+            break;
+    }
+
+    /* Try to initialize DUMMY_MAX_DIRECTBUFFERS direct buffers */
+    while( I_OUTPUTPICTURES < DUMMY_MAX_DIRECTBUFFERS )
+    {
+        p_pic = NULL;
+
+        /* Find an empty picture slot */
+        for( i_index = 0 ; i_index < VOUT_MAX_PICTURES ; i_index++ )
+        {
+            if( p_vout->p_picture[ i_index ].i_status == FREE_PICTURE )
+            {
+                p_pic = p_vout->p_picture + i_index;
+                break;
+            }
+        }
+
+        /* Allocate the picture */
+        if( p_pic == NULL || DummyNewPicture( p_vout, p_pic ) )
+        {
+            break;
+        }
+
+        p_pic->i_status = DESTROYED_PICTURE;
+        p_pic->i_type   = DIRECT_PICTURE;
+
+        PP_OUTPUTPICTURE[ I_OUTPUTPICTURES ] = p_pic;
+
+        I_OUTPUTPICTURES++;
+    }
+
     return( 0 );
 }
 
@@ -159,7 +168,14 @@ static int vout_Init( vout_thread_t *p_vout )
  *****************************************************************************/
 static void vout_End( vout_thread_t *p_vout )
 {
-    ;
+    int i_index;
+
+    /* Free the fake output buffers we allocated */
+    for( i_index = I_OUTPUTPICTURES ; i_index ; )
+    {
+        i_index--;
+        free( PP_OUTPUTPICTURE[ i_index ]->p_data_orig );
+    }
 }
 
 /*****************************************************************************
@@ -169,7 +185,6 @@ static void vout_End( vout_thread_t *p_vout )
  *****************************************************************************/
 static void vout_Destroy( vout_thread_t *p_vout )
 {
-    free( p_vout->p_sys->p_video );
     free( p_vout->p_sys );
 }
 
@@ -185,13 +200,95 @@ static int vout_Manage( vout_thread_t *p_vout )
 }
 
 /*****************************************************************************
- * vout_Display: displays previously rendered output
- *****************************************************************************
- * This function send the currently rendered image to dummy image, waits until
- * it is displayed and switch the two rendering buffers, preparing next frame.
+ * vout_Render: render previously calculated output
  *****************************************************************************/
-static void vout_Display( vout_thread_t *p_vout )
+static void vout_Render( vout_thread_t *p_vout, picture_t *p_pic )
 {
-    ;
+    /* No need to do anything, the fake direct buffers stay as they are */
+}
+
+/*****************************************************************************
+ * vout_Display: displays previously rendered output
+ *****************************************************************************/
+static void vout_Display( vout_thread_t *p_vout, picture_t *p_pic )
+{
+    /* No need to do anything, the fake direct buffers stay as they are */
+}
+
+/*****************************************************************************
+ * DummyNewPicture: allocate a picture
+ *****************************************************************************
+ * Returns 0 on success, -1 otherwise
+ *****************************************************************************/
+static int DummyNewPicture( vout_thread_t *p_vout, picture_t *p_pic )
+{
+    int i_width  = p_vout->output.i_width;
+    int i_height = p_vout->output.i_height;
+
+    switch( p_vout->output.i_chroma )
+    {
+    /* We know this chroma, allocate a buffer which will be used
+     * directly by the decoder */
+    case FOURCC_I420:
+    case FOURCC_IYUV:
+    case FOURCC_YV12:
+
+        /* Allocate the memory buffer */
+        p_pic->p_data = vlc_memalign( 16, i_width * i_height * 3 / 2,
+                                      &p_pic->p_data_orig );
+
+        /* Y buffer */
+        p_pic->Y_PIXELS = p_pic->p_data;
+        p_pic->p[Y_PLANE].i_lines = i_height;
+        p_pic->p[Y_PLANE].i_pitch = i_width;
+        p_pic->p[Y_PLANE].i_pixel_bytes = 1;
+        p_pic->p[Y_PLANE].b_margin = 0;
+
+        /* U buffer */
+        p_pic->U_PIXELS = p_pic->Y_PIXELS + i_height * i_width;
+        p_pic->p[U_PLANE].i_lines = i_height / 2;
+        p_pic->p[U_PLANE].i_pitch = i_width / 2;
+        p_pic->p[U_PLANE].i_pixel_bytes = 1;
+        p_pic->p[U_PLANE].b_margin = 0;
+
+        /* V buffer */
+        p_pic->V_PIXELS = p_pic->U_PIXELS + i_height * i_width / 4;
+        p_pic->p[V_PLANE].i_lines = i_height / 2;
+        p_pic->p[V_PLANE].i_pitch = i_width / 2;
+        p_pic->p[V_PLANE].i_pixel_bytes = 1;
+        p_pic->p[V_PLANE].b_margin = 0;
+
+        /* We allocated 3 planes */
+        p_pic->i_planes = 3;
+
+        return( 0 );
+        break;
+
+    /* Unknown chroma, allocate an RGB buffer, the video output's job
+     * will be to do the chroma->RGB conversion */
+    case FOURCC_RV16:
+
+        /* Allocate the memory buffer */
+        p_pic->p_data = vlc_memalign( 16, i_width * i_height * 2,
+                                      &p_pic->p_data_orig );
+
+        /* Fill important structures */
+        p_pic->p->p_pixels = p_pic->p_data;
+        p_pic->p->i_lines = i_height;
+        p_pic->p->i_pitch = i_width;
+        p_pic->p->i_pixel_bytes = 2;
+        p_pic->p->b_margin = 0;
+
+        /* We allocated 1 plane */
+        p_pic->i_planes = 1;
+
+        return( 0 );
+        break;
+
+    default:
+        p_pic->i_planes = 0;
+        return( 0 );
+        break;
+    }
 }
 
