@@ -2,7 +2,7 @@
  * dvd_ifo.c: Functions for ifo parsing
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: dvd_ifo.c,v 1.40 2001/11/07 17:37:16 stef Exp $
+ * $Id: dvd_ifo.c,v 1.46 2002/04/03 06:23:08 sam Exp $
  *
  * Authors: Stphane Borel <stef@via.ecp.fr>
  *          German Tischler <tanis@gaspode.franken.de>
@@ -30,12 +30,11 @@
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-#include "config.h"
-
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <videolan/vlc.h>
+
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
 #elif defined( _MSC_VER ) && defined( _WIN32 )
@@ -48,23 +47,13 @@
 #ifdef GOD_DAMN_DMCA
 #   include "dummy_dvdcss.h"
 #else
-#   include <videolan/dvdcss.h>
+#   include <dvdcss/dvdcss.h>
 #endif
 
-#include "config.h"
-#include "common.h"
-#include "threads.h"
-#include "mtime.h"
-
-#include "intf_msg.h"
-
-#include "input_dvd.h"
+#include "dvd.h"
 #include "dvd_ifo.h"
 #include "dvd_udf.h"
 
-#include "modules.h"
-#include "modules_export.h"
-
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
@@ -449,7 +438,7 @@ int IfoInit( ifo_t * p_ifo )
 /*****************************************************************************
  * IfoTitleSet: Parse vts*.ifo files to fill the Video Title Set structure.
  *****************************************************************************/
-int IfoTitleSet( ifo_t * p_ifo )
+int IfoTitleSet( ifo_t * p_ifo, int i_title )
 {
     u8          p_buf[DVD_LB_SIZE];
     u8 *        p_tmp;
@@ -464,7 +453,7 @@ int IfoTitleSet( ifo_t * p_ifo )
         FreeTitleSet( &p_ifo->vts );
     }
 
-    i_off = p_ifo->vmg.title_inf.p_attr[p_ifo->i_title-1].i_start_sector
+    i_off = p_ifo->vmg.title_inf.p_attr[i_title-1].i_start_sector
                    + p_ifo->i_start;
 
     //fprintf(stderr, "offset: %d\n" , i_off );
@@ -759,8 +748,8 @@ int IfoTitleSet( ifo_t * p_ifo )
     }
 #undef MGINF
 
-    intf_WarnMsg( 2, "ifo info: vts %d initialized",
-         p_ifo->vmg.title_inf.p_attr[p_ifo->i_title-1].i_title_set_num );
+    intf_WarnMsg( 4, "ifo info: vts %d initialized",
+         p_ifo->vmg.title_inf.p_attr[i_title-1].i_title_set_num );
 
     p_ifo->vts.b_initialized = 1;
 
