@@ -2,10 +2,11 @@
  * gtk_menu.c : functions to handle menu items.
  *****************************************************************************
  * Copyright (C) 2000, 2001 VideoLAN
- * $Id: gtk_menu.c,v 1.14 2001/11/11 18:15:41 sam Exp $
+ * $Id: gtk_menu.c,v 1.23 2002/03/14 01:35:28 stef Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Stphane Borel <stef@via.ecp.fr>
+ *          Johan Bilien <jobi@via.ecp.fr>
  *      
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,33 +26,24 @@
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
 #include <sys/types.h>                                              /* off_t */
 #include <stdlib.h>
 
-#define gtk 12
-#define gnome 42
-#if ( MODULE_NAME == gtk )
-#   include <gtk/gtk.h>
-#elif ( MODULE_NAME == gnome )
+#include <videolan/vlc.h>
+
+#ifdef MODULE_NAME_IS_gnome
 #   include <gnome.h>
+#else
+#   include <gtk/gtk.h>
 #endif
-#undef gtk
-#undef gnome
 
 #include <string.h>
 
-#include "config.h"
-#include "common.h"
-#include "threads.h"
-#include "mtime.h"
-
 #include "stream_control.h"
 #include "input_ext-intf.h"
 
 #include "interface.h"
 #include "intf_playlist.h"
-#include "intf_msg.h"
 
 #include "video.h"
 #include "video_output.h"
@@ -61,11 +53,7 @@
 #include "gtk_interface.h"
 #include "gtk_support.h"
 #include "gtk_playlist.h"
-#include "intf_gtk.h"
-
-#include "main.h"
-
-#include "modules_export.h"
+#include "gtk_common.h"
 
 /*
  * Local Prototypes
@@ -82,8 +70,6 @@ static gint GtkTitleMenu( gpointer, GtkWidget *,
 static gint GtkRadioMenu( intf_thread_t *, GtkWidget *, GSList *,
                           char *, int, int,
                    void( *pf_toggle )( GtkCheckMenuItem *, gpointer ) );
-void GtkMenubarAngleToggle( GtkCheckMenuItem *, gpointer );
-void GtkPopupAngleToggle( GtkCheckMenuItem *, gpointer );
 
 gint GtkSetupMenus( intf_thread_t * p_intf );
 
@@ -107,7 +93,8 @@ gint GtkSetupMenus( intf_thread_t * p_intf );
                    GTK_OBJECT( p_intf->p_sys->window ), (menu) ) );     \
         p_es = (es_descriptor_t*)user_data;                             \
                                                                         \
-        input_ToggleES( p_intf->p_input, p_es, menuitem->active );      \
+        input_ToggleES( p_input_bank->pp_input[0],                      \
+                        p_es, menuitem->active );                       \
                                                                         \
         p_intf->p_sys->b_update = menuitem->active;                     \
                                                                         \
@@ -171,27 +158,60 @@ void GtkPopupNavigationToggle( GtkCheckMenuItem * menuitem,
         gint i_title   = DATA2TITLE( user_data );
         gint i_chapter = DATA2CHAPTER( user_data );
 
-        p_area = p_intf->p_input->stream.p_selected_area;
+        p_area = p_input_bank->pp_input[0]->stream.p_selected_area;
 
-        if( p_area != p_intf->p_input->stream.pp_areas[i_title] )
+        if( p_area != p_input_bank->pp_input[0]->stream.pp_areas[i_title] )
         {
-            p_area = p_intf->p_input->stream.pp_areas[i_title];
+            p_area = p_input_bank->pp_input[0]->stream.pp_areas[i_title];
             p_intf->p_sys->b_title_update = 1;
         }
 
         p_area->i_part = i_chapter;
 
-        input_ChangeArea( p_intf->p_input, (input_area_t*)p_area );
+        input_ChangeArea( p_input_bank->pp_input[0], (input_area_t*)p_area );
 
         p_intf->p_sys->b_chapter_update = 1;
-        vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
+        vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );
         GtkSetupMenus( p_intf );
-        vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
+        vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock );
 
-        input_SetStatus( p_intf->p_input, INPUT_STATUS_PLAY );
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_PLAY );
     }
 }
 
+/*
+ * Program
+ */
+#define GTKPROGRAMTOGGLE( intf )                                            \
+    intf_thread_t * p_intf = GetIntf( GTK_WIDGET(menuitem), intf );         \
+                                                                            \
+    if( menuitem->active && !p_intf->p_sys->b_program_update )              \
+    {                                                                       \
+        u16 i_program_id = (ptrdiff_t)user_data;                            \
+                                                                            \
+        input_ChangeProgram( p_input_bank->pp_input[0], i_program_id );     \
+                                                                            \
+        p_intf->p_sys->b_program_update = 1;                                \
+                                                                            \
+        vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );   \
+        GtkSetupMenus( p_intf );                                            \
+        vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock ); \
+                                                                            \
+        p_intf->p_sys->b_program_update = 0;                                \
+                                                                            \
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_PLAY );    \
+    }
+
+void GtkMenubarProgramToggle( GtkCheckMenuItem * menuitem, gpointer user_data )
+{
+    GTKPROGRAMTOGGLE( "intf_window" );
+}
+
+void GtkPopupProgramToggle( GtkCheckMenuItem * menuitem, gpointer user_data )
+{
+    GTKPROGRAMTOGGLE( "intf_popup" );
+}
+
 /*
  * Title
  */
@@ -203,16 +223,16 @@ void GtkMenubarTitleToggle( GtkCheckMenuItem * menuitem, gpointer user_data )
     if( menuitem->active && !p_intf->p_sys->b_title_update )
     {
         gint i_title = (gint)((long)user_data);
-        input_ChangeArea( p_intf->p_input,
-                          p_intf->p_input->stream.pp_areas[i_title] );
+        input_ChangeArea( p_input_bank->pp_input[0],
+                          p_input_bank->pp_input[0]->stream.pp_areas[i_title] );
 
         p_intf->p_sys->b_title_update = 1;
-        vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
+        vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );
         GtkSetupMenus( p_intf );
-        vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
+        vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock );
         p_intf->p_sys->b_title_update = 0;
 
-        input_SetStatus( p_intf->p_input, INPUT_STATUS_PLAY );
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_PLAY );
 
     }
 }
@@ -226,79 +246,32 @@ void GtkMenubarChapterToggle( GtkCheckMenuItem * menuitem, gpointer user_data )
     intf_thread_t * p_intf;
     input_area_t *  p_area;
     gint            i_chapter;
-    char            psz_chapter[5];
     GtkWidget *     p_popup_menu;
 
     p_intf    = GetIntf( GTK_WIDGET(menuitem), "intf_window" );
-    p_area    = p_intf->p_input->stream.p_selected_area;
+    p_area    = p_input_bank->pp_input[0]->stream.p_selected_area;
     i_chapter = (gint)((long)user_data);
 
     if( menuitem->active && !p_intf->p_sys->b_chapter_update )
     {
         p_area->i_part = i_chapter;
-        input_ChangeArea( p_intf->p_input, (input_area_t*)p_area );
-
-        snprintf( psz_chapter, 4, "%02d", p_area->i_part );
-        psz_chapter[ 4 ] = '\0';
-        gtk_label_set_text( p_intf->p_sys->p_label_chapter, psz_chapter );
+        input_ChangeArea( p_input_bank->pp_input[0], (input_area_t*)p_area );
 
         p_intf->p_sys->b_chapter_update = 1;
         p_popup_menu = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT( 
                              p_intf->p_sys->p_popup ), "popup_navigation" ) );
 
-        vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
+        vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );
         GtkTitleMenu( p_intf, p_popup_menu, GtkPopupNavigationToggle );
-        vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
+        vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock );
 
         p_intf->p_sys->b_chapter_update = 0;
 
-        input_SetStatus( p_intf->p_input, INPUT_STATUS_PLAY );
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_PLAY );
     }
 }
 
 
-/*
- * Angle
- */
-
-#define GTKANGLETOGGLE( intf, window, menu, callback )                      \
-    intf_thread_t * p_intf;                                                 \
-    GtkWidget *     p_menu;                                                 \
-    input_area_t *  p_area;                                                 \
-                                                                            \
-    p_intf    = GetIntf( GTK_WIDGET(menuitem), (intf) );                    \
-                                                                            \
-    if( menuitem->active && !p_intf->p_sys->b_angle_update )                \
-    {                                                                       \
-        p_menu    = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT(            \
-                                p_intf->p_sys->window ), (menu) ) );        \
-        p_area    = p_intf->p_input->stream.p_selected_area;                \
-        p_area->i_angle = (gint)((long)user_data);                          \
-                                                                            \
-        input_ChangeArea( p_intf->p_input, (input_area_t*)p_area );         \
-                                                                            \
-        p_intf->p_sys->b_angle_update = 1;                                  \
-        vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );             \
-        GtkRadioMenu( p_intf, p_menu, NULL, "Angle",                        \
-                      p_area->i_angle_nb, p_area->i_angle, (callback) );    \
-        vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );           \
-        p_intf->p_sys->b_angle_update = 0;                                  \
-    }
-
-void GtkMenubarAngleToggle( GtkCheckMenuItem * menuitem, gpointer user_data )
-{
-    GTKANGLETOGGLE( "intf_window", p_popup, "popup_angle",
-                    GtkPopupAngleToggle );
-}
-
-void GtkPopupAngleToggle( GtkCheckMenuItem * menuitem, gpointer user_data )
-{
-    GTKANGLETOGGLE( "intf_popup", p_window, "menubar_angle",
-                    GtkMenubarAngleToggle );
-}
-
-#undef GTKANGLETOGGLE
-
 /****************************************************************************
  * Functions to generate menus
  ****************************************************************************/
@@ -404,10 +377,8 @@ static gint GtkRadioMenu( intf_thread_t * p_intf,
      * We have to release the lock since input_ToggleES needs it */
     if( p_item_selected != NULL )
     {
-        vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
         gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( p_item_selected ),
                                         TRUE );
-        vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
     }
 
     /* be sure that menu is sensitive, if there are several items */
@@ -419,6 +390,93 @@ static gint GtkRadioMenu( intf_thread_t * p_intf,
     return TRUE;
 }
 
+/*****************************************************************************
+ * GtkProgramMenu: update the programs menu of the interface 
+ *****************************************************************************
+ * Builds the program menu according to what have been found in the PAT 
+ * by the input. Usefull for multi-programs streams such as DVB ones.
+ *****************************************************************************/
+static gint GtkProgramMenu( gpointer            p_data,
+                            GtkWidget *         p_root,
+                            pgrm_descriptor_t * p_pgrm,
+                      void(*pf_toggle )( GtkCheckMenuItem *, gpointer ) )
+{
+    intf_thread_t *     p_intf;
+    GtkWidget *         p_menu;
+    GtkWidget *         p_item;
+    GtkWidget *         p_item_active;
+    GSList *            p_group;
+    char                psz_name[ GTK_MENU_LABEL_SIZE ];
+    gint                i;
+
+    /* cast */
+    p_intf = (intf_thread_t *)p_data;
+
+    /* temporary hack to avoid blank menu when an open menu is removed */
+    if( GTK_MENU_ITEM(p_root)->submenu != NULL )
+    {
+        gtk_menu_popdown( GTK_MENU( GTK_MENU_ITEM(p_root)->submenu ) );
+    }
+    /* removes previous menu */
+    gtk_menu_item_remove_submenu( GTK_MENU_ITEM( p_root ) );
+    gtk_widget_set_sensitive( p_root, FALSE );
+
+    p_group = NULL;
+
+    /* menu container */
+    p_menu = gtk_menu_new();
+
+    p_item_active = NULL;
+
+    /* create a set of program buttons and append them to the container */
+    for( i = 0 ; i < p_input_bank->pp_input[0]->stream.i_pgrm_number ; i++ )
+    {
+        snprintf( psz_name, GTK_MENU_LABEL_SIZE, "id %d",
+            p_input_bank->pp_input[0]->stream.pp_programs[i]->i_number );
+        psz_name[GTK_MENU_LABEL_SIZE-1] = '\0';
+            
+        p_item = gtk_radio_menu_item_new_with_label( p_group, psz_name );
+        p_group =
+            gtk_radio_menu_item_group( GTK_RADIO_MENU_ITEM( p_item ) );
+
+        if( p_pgrm == p_input_bank->pp_input[0]->stream.pp_programs[i] )
+        {
+            /* don't lose p_item when we append into menu */
+            p_item_active = p_item;
+        }
+
+        gtk_widget_show( p_item );
+
+        /* setup signal hanling */
+        gtk_signal_connect( GTK_OBJECT( p_item ), "toggled",
+                        GTK_SIGNAL_FUNC( pf_toggle ),
+                        (gpointer)(ptrdiff_t)( p_input_bank->pp_input[0]->
+                        stream.pp_programs[i]->i_number ) );
+
+        gtk_menu_append( GTK_MENU( p_menu ), p_item );
+    }
+
+    /* link the new menu to the menubar item */
+    gtk_menu_item_set_submenu( GTK_MENU_ITEM( p_root ), p_menu );
+
+    /* activation will call signals so we can only do it
+     * when submenu is attached to menu - to get intf_window 
+     * We have to release the lock since input_ToggleES needs it */
+    if( p_item_active != NULL )
+    {
+        gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( p_item_active ),
+                                        TRUE );
+    }
+
+    /* be sure that menu is sensitive if more than 1 program */
+    if( p_input_bank->pp_input[0]->stream.i_pgrm_number > 1 )
+    {
+        gtk_widget_set_sensitive( p_root, TRUE );
+    }
+
+    return TRUE;
+}
+
 /*****************************************************************************
  * GtkLanguageMenus: update interactive menus of the interface
  *****************************************************************************
@@ -429,10 +487,10 @@ static gint GtkRadioMenu( intf_thread_t * p_intf,
  * function, the interface lock has to be taken
  *****************************************************************************/
 static gint GtkLanguageMenus( gpointer          p_data,
-                                GtkWidget *       p_root,
-                                es_descriptor_t * p_es,
-                                gint              i_cat,
-                          void(*pf_toggle )( GtkCheckMenuItem *, gpointer ) )
+                              GtkWidget *       p_root,
+                              es_descriptor_t * p_es,
+                              gint              i_cat,
+                        void(*pf_toggle )( GtkCheckMenuItem *, gpointer ) )
 {
     intf_thread_t *     p_intf;
     GtkWidget *         p_menu;
@@ -486,15 +544,20 @@ static gint GtkLanguageMenus( gpointer          p_data,
     p_item_active = NULL;
     i_item = 0;
 
-    vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
+    vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );
 
+#define ES p_input_bank->pp_input[0]->stream.pp_es[i]
     /* create a set of language buttons and append them to the container */
-    for( i = 0 ; i < p_intf->p_input->stream.i_es_number ; i++ )
+    for( i = 0 ; i < p_input_bank->pp_input[0]->stream.i_es_number ; i++ )
     {
-        if( p_intf->p_input->stream.pp_es[i]->i_cat == i_cat )
+        if( ( ES->i_cat == i_cat ) &&
+            ( !ES->p_pgrm ||
+              ES->p_pgrm ==
+                 p_input_bank->pp_input[0]->stream.p_selected_program ) )
         {
             i_item++;
-            strcpy( psz_name, p_intf->p_input->stream.pp_es[i]->psz_desc );
+            strcpy( psz_name,
+                    p_input_bank->pp_input[0]->stream.pp_es[i]->psz_desc );
             if( psz_name[0] == '\0' )
             {
                 snprintf( psz_name, GTK_MENU_LABEL_SIZE,
@@ -506,7 +569,7 @@ static gint GtkLanguageMenus( gpointer          p_data,
             p_group =
                 gtk_radio_menu_item_group( GTK_RADIO_MENU_ITEM( p_item ) );
 
-            if( p_es == p_intf->p_input->stream.pp_es[i] )
+            if( p_es == p_input_bank->pp_input[0]->stream.pp_es[i] )
             {
                 /* don't lose p_item when we append into menu */
                 p_item_active = p_item;
@@ -517,13 +580,13 @@ static gint GtkLanguageMenus( gpointer          p_data,
             /* setup signal hanling */
             gtk_signal_connect( GTK_OBJECT( p_item ), "toggled",
                             GTK_SIGNAL_FUNC( pf_toggle ),
-                            (gpointer)( p_intf->p_input->stream.pp_es[i] ) );
+                            (gpointer)( p_input_bank->pp_input[0]->stream.pp_es[i] ) );
 
             gtk_menu_append( GTK_MENU( p_menu ), p_item );
         }
     }
 
-    vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
+    vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock );
 
     /* link the new menu to the menubar item */
     gtk_menu_item_set_submenu( GTK_MENU_ITEM( p_root ), p_menu );
@@ -595,7 +658,7 @@ static gint GtkTitleMenu( gpointer       p_data,
     p_chapter_submenu = NULL;
     p_chapter_menu_item = NULL;
     p_item_active = NULL;
-    i_title_nb = p_intf->p_input->stream.i_area_nb;
+    i_title_nb = p_input_bank->pp_input[0]->stream.i_area_nb;
 
     /* loop on titles */
     for( i_title = 1 ; i_title < i_title_nb ; i_title++ )
@@ -619,7 +682,7 @@ static gint GtkTitleMenu( gpointer       p_data,
         }
 
         snprintf( psz_name, GTK_MENU_LABEL_SIZE, "Title %d (%d)", i_title,
-                  p_intf->p_input->stream.pp_areas[i_title]->i_part_nb );
+                  p_input_bank->pp_input[0]->stream.pp_areas[i_title]->i_part_nb );
         psz_name[ GTK_MENU_LABEL_SIZE - 1 ] = '\0';
 #if 0
         if( pf_toggle == on_menubar_title_toggle )
@@ -629,8 +692,8 @@ static gint GtkTitleMenu( gpointer       p_data,
             p_title_group =
               gtk_radio_menu_item_group( GTK_RADIO_MENU_ITEM( p_title_item ) );
 
-            if( p_intf->p_input->stream.pp_areas[i_title] ==
-                         p_intf->p_input->stream.p_selected_area )
+            if( p_input_bank->pp_input[0]->stream.pp_areas[i_title] ==
+                         p_input_bank->pp_input[0]->stream.p_selected_area )
             {
                 p_item_active = p_title_item;
             }
@@ -639,9 +702,9 @@ static gint GtkTitleMenu( gpointer       p_data,
             gtk_signal_connect( GTK_OBJECT( p_title_item ),
                      "toggled",
                      GTK_SIGNAL_FUNC( pf_toggle ),
-                     (gpointer)(p_intf->p_input->stream.pp_areas[i_title]) );
+                     (gpointer)(p_input_bank->pp_input[0]->stream.pp_areas[i_title]) );
 
-            if( p_intf->p_input->stream.i_area_nb > 1 )
+            if( p_input_bank->pp_input[0]->stream.i_area_nb > 1 )
             {
                 /* be sure that menu is sensitive */
                 gtk_widget_set_sensitive( p_navigation, TRUE );
@@ -655,7 +718,7 @@ static gint GtkTitleMenu( gpointer       p_data,
 #if 1    
             p_chapter_menu = gtk_menu_new();
             i_chapter_nb =
-                    p_intf->p_input->stream.pp_areas[i_title]->i_part_nb;
+                    p_input_bank->pp_input[0]->stream.pp_areas[i_title]->i_part_nb;
     
             for( i_chapter = 0 ; i_chapter < i_chapter_nb ; i_chapter++ )
             {
@@ -690,8 +753,9 @@ static gint GtkTitleMenu( gpointer       p_data,
                                                 GTK_RADIO_MENU_ITEM( p_item ) );
                 gtk_widget_show( p_item );
 
-#define p_area p_intf->p_input->stream.pp_areas[i_title]
-                if( ( p_area == p_intf->p_input->stream.p_selected_area ) &&
+#define p_area p_input_bank->pp_input[0]->stream.pp_areas[i_title]
+                if( ( p_area ==
+                        p_input_bank->pp_input[0]->stream.p_selected_area ) &&
                     ( p_area->i_part == i_chapter + 1 ) )
                 {
                     p_item_active = p_item;
@@ -726,18 +790,18 @@ static gint GtkTitleMenu( gpointer       p_data,
             gtk_menu_item_set_submenu( GTK_MENU_ITEM( p_title_item ),
                                        p_chapter_menu );
 
-            if( p_intf->p_input->stream.pp_areas[i_title]->i_part_nb > 1 )
+            if( p_input_bank->pp_input[0]->stream.pp_areas[i_title]->i_part_nb > 1 )
             {
                 /* be sure that menu is sensitive */
                 gtk_widget_set_sensitive( p_navigation, TRUE );
             }
 #else
-        GtkRadioMenu( p_intf, p_title_item, p_chapter_group, "Chapter",
-                        p_intf->p_input->stream.pp_areas[i_title]->i_part_nb,
-                        i_title * 100,
-                        p_intf->p_input->stream.p_selected_area->i_part +
-                            p_intf->p_input->stream.p_selected_area->i_id *100,
-                        pf_toggle );
+            GtkRadioMenu( p_intf, p_title_item, p_chapter_group, "Chapter",
+                p_input_bank->pp_input[0]->stream.pp_areas[i_title]->i_part_nb,
+                i_title * 100,
+                p_input_bank->pp_input[0]->stream.p_selected_area->i_part +
+                p_input_bank->pp_input[0]->stream.p_selected_area->i_id *100,
+                pf_toggle );
 
 #endif
         }
@@ -770,13 +834,11 @@ static gint GtkTitleMenu( gpointer       p_data,
      * We have to release the lock since input_ToggleES needs it */
     if( p_item_active != NULL )
     {
-        vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
         gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( p_item_active ),
                                         TRUE );
-        vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
     }
 #if 0
-    if( p_intf->p_input->stream.i_area_nb > 1 )
+    if( p_input_bank->pp_input[0]->stream.i_area_nb > 1 )
     {
         /* be sure that menu is sensitive */
         gtk_widget_set_sensitive( p_navigation, TRUE );
@@ -789,6 +851,8 @@ static gint GtkTitleMenu( gpointer       p_data,
 /*****************************************************************************
  * GtkSetupMenus: function that generates title/chapter/audio/subpic
  * menus with help from preceding functions
+ *****************************************************************************
+ * Function called with the lock on stream
  *****************************************************************************/
 gint GtkSetupMenus( intf_thread_t * p_intf )
 {
@@ -799,12 +863,38 @@ gint GtkSetupMenus( intf_thread_t * p_intf )
     gint                i;
 
     p_intf->p_sys->b_chapter_update |= p_intf->p_sys->b_title_update;
-    p_intf->p_sys->b_angle_update |= p_intf->p_sys->b_title_update;
-    p_intf->p_sys->b_audio_update |= p_intf->p_sys->b_title_update;
-    p_intf->p_sys->b_spu_update |= p_intf->p_sys->b_title_update;
+    p_intf->p_sys->b_audio_update |= p_intf->p_sys->b_title_update |
+                                     p_intf->p_sys->b_program_update;
+    p_intf->p_sys->b_spu_update |= p_intf->p_sys->b_title_update |
+                                   p_intf->p_sys->b_program_update;
 
-//    vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
+    if( p_intf->p_sys->b_program_update )
+    { 
+        pgrm_descriptor_t * p_pgrm;
+        
+        if( p_input_bank->pp_input[0]->stream.p_new_program )
+        {
+            p_pgrm = p_input_bank->pp_input[0]->stream.p_new_program;
+        }
+        else
+        {
+            p_pgrm = p_input_bank->pp_input[0]->stream.p_selected_program;
+        }
 
+        p_menubar_menu = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT( 
+                            p_intf->p_sys->p_window ), "menubar_program" ) );
+        GtkProgramMenu( p_intf, p_menubar_menu, p_pgrm,
+                        GtkMenubarProgramToggle );
+        
+        p_intf->p_sys->b_program_update = 1;
+        p_popup_menu = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT( 
+                            p_intf->p_sys->p_popup ), "popup_program" ) );
+        GtkProgramMenu( p_intf, p_popup_menu, p_pgrm,
+                        GtkPopupProgramToggle );
+
+        p_intf->p_sys->b_program_update = 0;
+    }
+    
     if( p_intf->p_sys->b_title_update )
     { 
         char            psz_title[5];
@@ -812,12 +902,12 @@ gint GtkSetupMenus( intf_thread_t * p_intf )
         p_menubar_menu = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT( 
                             p_intf->p_sys->p_window ), "menubar_title" ) );
         GtkRadioMenu( p_intf, p_menubar_menu, NULL, "Title",
-                      p_intf->p_input->stream.i_area_nb - 1,
-                      p_intf->p_input->stream.p_selected_area->i_id,
+                      p_input_bank->pp_input[0]->stream.i_area_nb - 1,
+                      p_input_bank->pp_input[0]->stream.p_selected_area->i_id,
                       GtkMenubarTitleToggle );
 
         snprintf( psz_title, 4, "%d",
-                  p_intf->p_input->stream.p_selected_area->i_id );
+                  p_input_bank->pp_input[0]->stream.p_selected_area->i_id );
         psz_title[ 4 ] = '\0';
         gtk_label_set_text( p_intf->p_sys->p_label_title, psz_title );
 
@@ -833,8 +923,8 @@ gint GtkSetupMenus( intf_thread_t * p_intf )
         GtkTitleMenu( p_intf, p_popup_menu, GtkPopupNavigationToggle );
 #if 0
         GtkRadioMenu( p_intf, p_menubar_menu, NULL, "Title",
-                        p_intf->p_input->stream.i_area_nb - 1,
-                        p_intf->p_input->stream.p_selected_area->i_id,
+                        p_input_bank->pp_input[0]->stream.i_area_nb - 1,
+                        p_input_bank->pp_input[0]->stream.p_selected_area->i_id,
                         on_menubar_chapter_toggle );
 #endif
 
@@ -842,59 +932,40 @@ gint GtkSetupMenus( intf_thread_t * p_intf )
                              p_intf->p_sys->p_window ), "menubar_chapter" ) );
 
         GtkRadioMenu( p_intf, p_menubar_menu, NULL, "Chapter",
-                        p_intf->p_input->stream.p_selected_area->i_part_nb,
-                        p_intf->p_input->stream.p_selected_area->i_part,
+                        p_input_bank->pp_input[0]->stream.p_selected_area->i_part_nb,
+                        p_input_bank->pp_input[0]->stream.p_selected_area->i_part,
                         GtkMenubarChapterToggle );
 
 
         snprintf( psz_chapter, 4, "%d", 
-                  p_intf->p_input->stream.p_selected_area->i_part );
+                  p_input_bank->pp_input[0]->stream.p_selected_area->i_part );
         psz_chapter[ 4 ] = '\0';
         gtk_label_set_text( p_intf->p_sys->p_label_chapter, psz_chapter );
 
         p_intf->p_sys->i_part =
-                p_intf->p_input->stream.p_selected_area->i_part;
+                p_input_bank->pp_input[0]->stream.p_selected_area->i_part;
 
         p_intf->p_sys->b_chapter_update = 0;
     }
 
-    if( p_intf->p_sys->b_angle_update )
-    {
-        p_menubar_menu = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT( 
-                             p_intf->p_sys->p_window ), "menubar_angle" ) );
-        GtkRadioMenu( p_intf, p_menubar_menu, NULL, "Angle",
-                        p_intf->p_input->stream.p_selected_area->i_angle_nb,
-                        p_intf->p_input->stream.p_selected_area->i_angle,
-                        GtkMenubarAngleToggle );
-
-        p_popup_menu = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT( 
-                             p_intf->p_sys->p_popup ), "popup_angle" ) );
-        GtkRadioMenu( p_intf, p_popup_menu, NULL, "Angle",
-                        p_intf->p_input->stream.p_selected_area->i_angle_nb,
-                        p_intf->p_input->stream.p_selected_area->i_angle,
-                        GtkPopupAngleToggle );
-
-        p_intf->p_sys->b_angle_update = 0;
-    }
-    
     /* look for selected ES */
     p_audio_es = NULL;
     p_spu_es = NULL;
 
-    for( i = 0 ; i < p_intf->p_input->stream.i_selected_es_number ; i++ )
+    for( i = 0 ; i < p_input_bank->pp_input[0]->stream.i_selected_es_number ; i++ )
     {
-        if( p_intf->p_input->stream.pp_selected_es[i]->i_cat == AUDIO_ES )
+        if( p_input_bank->pp_input[0]->stream.pp_selected_es[i]->i_cat == AUDIO_ES )
         {
-            p_audio_es = p_intf->p_input->stream.pp_selected_es[i];
+            p_audio_es = p_input_bank->pp_input[0]->stream.pp_selected_es[i];
         }
 
-        if( p_intf->p_input->stream.pp_selected_es[i]->i_cat == SPU_ES )
+        if( p_input_bank->pp_input[0]->stream.pp_selected_es[i]->i_cat == SPU_ES )
         {
-            p_spu_es = p_intf->p_input->stream.pp_selected_es[i];
+            p_spu_es = p_input_bank->pp_input[0]->stream.pp_selected_es[i];
         }
     }
 
-    vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
+    vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock );
 
     /* audio menus */
     if( p_intf->p_sys->b_audio_update )
@@ -936,7 +1007,7 @@ gint GtkSetupMenus( intf_thread_t * p_intf )
         p_intf->p_sys->b_spu_update = 0;
     }
 
-    vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
+    vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );
 
     return TRUE;
 }
