@@ -2,7 +2,7 @@
  * ac3_imdct_common.c: common ac3 DCT functions
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: ac3_imdct_common.c,v 1.4 2001/11/28 15:08:05 massiot Exp $
+ * $Id: ac3_imdct_common.c,v 1.6 2001/12/30 07:09:55 sam Exp $
  *
  * Authors: Renaud Dartus <reno@videolan.org>
  *          Aaron Holtzman <aholtzma@engr.uvic.ca>
@@ -22,25 +22,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-/* MODULE_NAME defined in Makefile together with -DBUILTIN */
-#ifdef BUILTIN
-#   include "modules_inner.h"
-#else
-#   define _M( foo ) foo
-#endif
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
-#include <string.h>                                              /* memcpy() */
-
 #include <math.h>
 #include <stdio.h>
 
-#include "config.h"
-#include "common.h"
+#include <videolan/vlc.h>
 
 #include "ac3_imdct.h"
 #include "ac3_retables.h"
