@@ -2,7 +2,7 @@
  * motionmmxext.c : MMX EXT motion compensation module for vlc
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: motionmmxext.c,v 1.13 2001/11/28 15:08:05 massiot Exp $
+ * $Id: motionmmxext.c,v 1.16 2002/02/15 13:32:53 sam Exp $
  *
  * Authors: Aaron Holtzman <aholtzma@ess.engr.uvic.ca>
  *          Michel Lespinasse <walken@zoy.org>
@@ -22,29 +22,16 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-#define MODULE_NAME motionmmxext
-#include "modules_inner.h"
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <stdlib.h>                                      /* malloc(), free() */
 #include <string.h>
 
-#include "config.h"
-#include "common.h"                                     /* boolean_t, byte_t */
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
-#include "tests.h"
+#include <videolan/vlc.h>
 
 #include "mmx.h"
 
-#include "modules.h"
-#include "modules_export.h"
-
 /*****************************************************************************
  * Local and extern prototypes.
  *****************************************************************************/
@@ -54,14 +41,14 @@ static void motion_getfunctions( function_list_t * p_function_list );
  * Build configuration tree.
  *****************************************************************************/
 MODULE_CONFIG_START
-ADD_WINDOW( "Configuration for MMXEXT motion compensation module" )
-    ADD_COMMENT( "Ha, ha -- nothing to configure yet" )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    p_module->i_capabilities = MODULE_CAPABILITY_NULL
-                                | MODULE_CAPABILITY_MOTION;
-    p_module->psz_longname = "MMXEXT motion compensation module";
+    SET_DESCRIPTION( "MMXEXT motion compensation module" )
+    ADD_CAPABILITY( MOTION, 200 )
+    ADD_REQUIREMENT( MMXEXT )
+    ADD_SHORTCUT( "mmxext" )
+    ADD_SHORTCUT( "motionmmxext" )
 MODULE_INIT_STOP
 
 MODULE_ACTIVATE_START
@@ -71,25 +58,6 @@ MODULE_ACTIVATE_STOP
 MODULE_DEACTIVATE_START
 MODULE_DEACTIVATE_STOP
 
-/*****************************************************************************
- * motion_Probe: tests probe the CPU and return a score
- *****************************************************************************/
-static int motion_Probe( probedata_t *p_data )
-{
-    if( !TestCPU( CPU_CAPABILITY_MMXEXT ) )
-    {
-        return( 0 );
-    }
-
-    if( TestMethod( MOTION_METHOD_VAR, "motionmmxext" )
-         || TestMethod( MOTION_METHOD_VAR, "mmxext" ) )
-    {
-        return( 999 );
-    }
-
-    return( 200 );
-}
-
 /*****************************************************************************
  * Motion compensation in MMXEXT (OK I know this does 3DNow too and it's ugly)
  *****************************************************************************/
@@ -596,8 +564,6 @@ static void motion_getfunctions( function_list_t * p_function_list )
         }
     };
 
-    p_function_list->pf_probe = motion_Probe;
-
 #define list p_function_list->functions.motion
     memcpy( list.ppppf_motion, ppppf_motion, sizeof( void * ) * 16 );
 #undef list
