@@ -2,7 +2,7 @@
  * vpar_synchro.c : frame dropping routines
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: vpar_synchro.c,v 1.3 2001/12/07 18:33:08 sam Exp $
+ * $Id: vpar_synchro.c,v 1.8 2002/03/11 07:23:09 gbazin Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Samuel Hocevar <sam@via.ecp.fr>
@@ -94,19 +94,14 @@
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
+#include <stdlib.h>                                                /* free() */
 #include <string.h>                                    /* memcpy(), memset() */
 
-#include "common.h"
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
+#include <videolan/vlc.h>
 
 #include "video.h"
 #include "video_output.h"
 
-#include "modules_export.h"
 #include "stream_control.h"
 #include "input_ext-dec.h"
 
@@ -114,7 +109,6 @@
 #include "vpar_pool.h"
 #include "video_parser.h"
 
-
 /*
  * Local prototypes
  */
@@ -213,9 +207,6 @@ boolean_t vpar_SynchroChoose( vpar_thread_t * p_vpar, int i_coding_type,
         mtime_t         now, period, tau_yuv;
         mtime_t         pts = 0;
         boolean_t       b_decode = 0;
-#ifdef TRACE_VPAR
-        char            p_date[MSTRTIME_MAX_SIZE];
-#endif
 
         now = mdate();
         period = 1000000 * 1001 / p_vpar->sequence.i_frame_rate
@@ -304,13 +295,6 @@ boolean_t vpar_SynchroChoose( vpar_thread_t * p_vpar, int i_coding_type,
             }
         }
 
-#ifdef TRACE_VPAR
-        intf_DbgMsg("vpar synchro debug: %s picture scheduled for %s, %s (%lld)",
-                    i_coding_type == B_CODING_TYPE ? "B" :
-                    (i_coding_type == P_CODING_TYPE ? "P" : "I"),
-                    mstrtime(p_date, pts), b_decode ? "decoding" : "trashed",
-                    S.p_tau[i_coding_type]);
-#endif
         if( !b_decode )
         {
             S.i_not_chosen_pic++;
@@ -366,18 +350,6 @@ void vpar_SynchroEnd( vpar_thread_t * p_vpar, int i_coding_type,
                 p_vpar->synchro.pi_meaningful[i_coding_type]++;
             }
         }
-
-#ifdef TRACE_VPAR
-        intf_DbgMsg("vpar synchro debug: finished decoding %s (%lld)",
-                    i_coding_type == B_CODING_TYPE ? "B" :
-                    (i_coding_type == P_CODING_TYPE ? "P" : "I"), tau);
-#endif
-    }
-    else
-    {
-        intf_DbgMsg("vpar synchro debug: aborting %s",
-                    i_coding_type == B_CODING_TYPE ? "B" :
-                    (i_coding_type == P_CODING_TYPE ? "P" : "I"));
     }
 }
 
@@ -561,13 +533,18 @@ void vpar_SynchroNewPicture( vpar_thread_t * p_vpar, int i_coding_type,
  *****************************************************************************/
 static int SynchroType( void )
 {
-    char * psz_synchro = main_GetPszVariable( VPAR_SYNCHRO_VAR, NULL );
+    char psz_synchro_tmp[5];
+    char * psz_synchro = config_GetPszVariable( "vpar_synchro" );
 
     if( psz_synchro == NULL )
     {
         return VPAR_SYNCHRO_DEFAULT;
     }
 
+    strncpy( psz_synchro_tmp, psz_synchro, 5);
+    free( psz_synchro );
+    psz_synchro = psz_synchro_tmp;
+
     switch( *psz_synchro++ )
     {
       case 'i':
