@@ -20,29 +20,17 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-#define MODULE_NAME qnx 
-#include "modules_inner.h"
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <stdlib.h>                                      /* malloc(), free() */
 #include <string.h>
 
-#include "config.h"
-#include "common.h"                                     /* boolean_t, byte_t */
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
+#include <videolan/vlc.h>
 
 #include "video.h"
 #include "video_output.h"
 
-#include "modules.h"
-#include "modules_export.h"
-
 /*****************************************************************************
  * Capabilities defined in the other files.
  ******************************************************************************/
@@ -53,15 +41,13 @@ void _M( vout_getfunctions )( function_list_t * p_function_list );
  * Building configuration tree
  *****************************************************************************/
 MODULE_CONFIG_START
-ADD_WINDOW( "Configuration for QNX RTOS module" )
-    ADD_COMMENT( "For now, the QNX RTOS module cannot be configured" )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    p_module->psz_longname = "QNX RTOS module";
-    p_module->i_capabilities = MODULE_CAPABILITY_NULL
-                                | MODULE_CAPABILITY_AOUT
-                                | MODULE_CAPABILITY_VOUT;
+    SET_DESCRIPTION( "QNX RTOS module" )
+    ADD_CAPABILITY( VOUT, 100 )
+    ADD_CAPABILITY( AOUT, 50 )
+    ADD_SHORTCUT( "qnx" )
 MODULE_INIT_STOP
 
 MODULE_ACTIVATE_START
