@@ -2,7 +2,7 @@
  * sdl.c : SDL plugin for vlc
  *****************************************************************************
  * Copyright (C) 2000, 2001 VideoLAN
- * $Id: sdl.c,v 1.16 2001/05/30 17:03:12 sam Exp $
+ * $Id: sdl.c,v 1.19 2001/12/30 07:09:56 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Pierre Baillet <oct@zoy.org>
@@ -23,29 +23,19 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-#define MODULE_NAME sdl
-#include "modules_inner.h"
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <stdlib.h>                                      /* malloc(), free() */
+#include <string.h>
 
-#include "config.h"
-#include "common.h"                                     /* boolean_t, byte_t */
-#include "threads.h"
-#include "mtime.h"
+#include <videolan/vlc.h>
 
 #include "audio_output.h"
 
 #include "video.h"
 #include "video_output.h"
 
-#include "modules.h"
-#include "modules_export.h"
-
 /*****************************************************************************
  * Capabilities defined in the other files.
  *****************************************************************************/
@@ -56,15 +46,13 @@ void _M( vout_getfunctions )( function_list_t * p_function_list );
  * Building configuration tree
  *****************************************************************************/
 MODULE_CONFIG_START
-ADD_WINDOW( "Configuration for SDL module" )
-    ADD_COMMENT( "For now, the SDL module cannot be configured" )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    p_module->i_capabilities = MODULE_CAPABILITY_NULL
-                                | MODULE_CAPABILITY_VOUT
-                                | MODULE_CAPABILITY_AOUT;
-    p_module->psz_longname = "Simple DirectMedia Layer module";
+    SET_DESCRIPTION( "Simple DirectMedia Layer module" )
+    ADD_CAPABILITY( AOUT, 40 )
+    ADD_CAPABILITY( VOUT, 100 )
+    ADD_SHORTCUT( "sdl" )
 MODULE_INIT_STOP
 
 MODULE_ACTIVATE_START
