@@ -2,7 +2,7 @@
  * intf_playlist.c : Playlist management functions
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: intf_playlist.c,v 1.11 2001/12/07 18:33:08 sam Exp $
+ * $Id: intf_playlist.c,v 1.13 2002/01/10 04:11:25 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -20,16 +20,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
-#include "defs.h"
-
 #include <stdlib.h>                                      /* free(), strtol() */
 #include <stdio.h>                                              /* sprintf() */
 #include <string.h>                                            /* strerror() */
 #include <errno.h>                                                 /* ENOMEM */
 
-#include "common.h"
-#include "intf_msg.h"
-#include "threads.h"
+#include <videolan/vlc.h>
 
 #include "intf_playlist.h"
 
@@ -249,21 +245,24 @@ void intf_PlaylistJumpto( playlist_t * p_playlist , int i_pos)
 {
     vlc_mutex_lock( &p_playlist->change_lock );
 
-    p_playlist->i_index = i_pos;
+    if( i_pos < -1 )
+    {
+        i_pos = -1;
+    }
 
-    if( p_playlist->i_index != -1 )
+    if( i_pos != -1 )
     {
         if( p_playlist->current.psz_name != NULL )
         {
             free( p_playlist->current.psz_name );
         }
 
-        p_playlist->current = p_playlist->p_item[ p_playlist->i_index ];
-        p_playlist->current.psz_name
-                            = strdup( p_playlist->current.psz_name );
-
+        p_playlist->current = p_playlist->p_item[ i_pos ];
+        p_playlist->current.psz_name = strdup( p_playlist->current.psz_name );
     }
-    p_main->p_playlist->b_stopped = 0;
+
+    p_playlist->i_index = i_pos;
+    p_playlist->b_stopped = 0;
 
     vlc_mutex_unlock( &p_playlist->change_lock );
 }
