@@ -4,7 +4,7 @@
  * and spawn threads.
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: main.c,v 1.175 2002/04/02 23:43:57 gbazin Exp $
+ * $Id: main.c,v 1.179 2002/04/17 11:43:31 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -195,9 +195,6 @@
 #define FILTER_TEXT "video filter module"
 #define FILTER_LONGTEXT NULL
 
-#define INPUT_TEXT "input method"
-#define INPUT_LONGTEXT NULL
-
 #define SERVER_PORT_TEXT "server port"
 #define SERVER_PORT_LONGTEXT NULL
 
@@ -213,6 +210,10 @@
 #define IFACE_TEXT "network interface"
 #define IFACE_LONGTEXT NULL
 
+#define INPUT_PROGRAM_TEXT "choose program (SID)"
+#define INPUT_PROGRAM_LONGTEXT "choose the program to select by giving its"\
+                                "Service ID"
+
 #define INPUT_AUDIO_TEXT "choose audio"
 #define INPUT_AUDIO_LONGTEXT NULL
 
@@ -234,9 +235,24 @@
 #define SAT_POL_TEXT "Satellite transponder polarization"
 #define SAT_POL_LONGTEXT NULL
 
+#define SAT_FEC_TEXT "Satellite transponder FEC"
+#define SAT_FEC_LONGTEXT NULL
+
 #define SAT_SRATE_TEXT "Satellite transponder symbol rate"
 #define SAT_SRATE_LONGTEXT NULL
 
+#define SAT_DISEQC_TEXT "Use diseqc with antenna"
+#define SAT_DISEQC_LONGTEXT NULL
+
+#define SAT_LNB_LOF1_TEXT "Antenna lnb_lof1 (kHz)"
+#define SAT_LNB_LOF1_LONGTEXT NULL
+
+#define SAT_LNB_LOF2_TEXT "Antenna lnb_lof2 (kHz)"
+#define SAT_LNB_LOF2_LONGTEXT NULL
+
+#define SAT_LNB_SLOF_TEXT "Antenna lnb_slof (kHz)"
+#define SAT_LNB_SLOF_LONGTEXT NULL
+
 #define IPV6_TEXT "force IPv6"
 #define IPV6_LONGTEXT NULL
 
@@ -334,13 +350,14 @@ ADD_PLUGIN  ( "filter", MODULE_CAPABILITY_VOUT, NULL, NULL, FILTER_TEXT, FILTER_
 
 /* Input options */
 ADD_CATEGORY_HINT( "Input", NULL )
-ADD_STRING  ( "input", NULL, NULL, INPUT_TEXT, INPUT_LONGTEXT )
 ADD_INTEGER ( "server_port", 1234, NULL, SERVER_PORT_TEXT, SERVER_PORT_LONGTEXT )
 ADD_BOOL    ( "network_channel", NULL, NETCHANNEL_TEXT, NETCHANNEL_LONGTEXT )
 ADD_STRING  ( "channel_server", "localhost", NULL, CHAN_SERV_TEXT, CHAN_SERV_LONGTEXT )
 ADD_INTEGER ( "channel_port", 6010, NULL, CHAN_PORT_TEXT, CHAN_PORT_LONGTEXT )
 ADD_STRING  ( "iface", "eth0", NULL, IFACE_TEXT, IFACE_LONGTEXT )
 
+ADD_INTEGER ( "input_program", 0, NULL, INPUT_PROGRAM_TEXT,
+        INPUT_PROGRAM_LONGTEXT )
 ADD_INTEGER ( "input_audio", -1, NULL, INPUT_AUDIO_TEXT, INPUT_AUDIO_LONGTEXT )
 ADD_INTEGER ( "input_channel", -1, NULL, INPUT_CHAN_TEXT, INPUT_CHAN_LONGTEXT )
 ADD_INTEGER ( "input_subtitle", -1, NULL, INPUT_SUBT_TEXT, INPUT_SUBT_LONGTEXT )
@@ -348,10 +365,18 @@ ADD_INTEGER ( "input_subtitle", -1, NULL, INPUT_SUBT_TEXT, INPUT_SUBT_LONGTEXT )
 ADD_STRING  ( "dvd_device", "/dev/dvd", NULL, DVD_DEV_TEXT, DVD_DEV_LONGTEXT )
 ADD_STRING  ( "vcd_device", "/dev/cdrom", NULL, VCD_DEV_TEXT, VCD_DEV_LONGTEXT )
 #ifdef HAVE_SATELLITE
-ADD_INTEGER ( "sat_frequency", 12553, NULL, SAT_FREQ_TEXT, SAT_FREQ_LONGTEXT )
+ADD_INTEGER ( "sat_frequency", 11954, NULL, SAT_FREQ_TEXT, SAT_FREQ_LONGTEXT )
 ADD_INTEGER ( "sat_polarization", 0, NULL, SAT_POL_TEXT, SAT_POL_LONGTEXT )
+ADD_INTEGER ( "sat_fec", 3, NULL, SAT_FEC_TEXT, SAT_FEC_LONGTEXT )
 ADD_INTEGER ( "sat_symbol_rate", 27500, NULL, SAT_SRATE_TEXT,
             SAT_SRATE_LONGTEXT )
+ADD_BOOL    ( "sat_diseqc", 0, SAT_DISEQC_TEXT, SAT_DISEQC_LONGTEXT )
+ADD_INTEGER ( "sat_lnb_lof1", 10000, NULL, SAT_LNB_LOF1_TEXT, 
+            SAT_LNB_LOF1_LONGTEXT )
+ADD_INTEGER ( "sat_lnb_lof2", 10000, NULL, SAT_LNB_LOF2_TEXT, 
+            SAT_LNB_LOF2_LONGTEXT )
+ADD_INTEGER ( "sat_lnb_slof", 11700, NULL, SAT_LNB_SLOF_TEXT, 
+            SAT_LNB_SLOF_LONGTEXT )
 #endif
 
 ADD_BOOL    ( "ipv6", NULL, IPV6_TEXT, IPV6_LONGTEXT )
@@ -732,8 +757,8 @@ int main( int i_argc, char *ppsz_argv[], char *ppsz_env[] )
      * Choose the best memcpy module
      */
     psz_plugin = config_GetPszVariable( "memcpy" );
-    p_main->p_memcpy_module = module_Need( MODULE_CAPABILITY_MEMCPY, NULL,
-                                           psz_plugin );
+    p_main->p_memcpy_module = module_Need( MODULE_CAPABILITY_MEMCPY,
+                                           psz_plugin, NULL );
     if( psz_plugin ) free( psz_plugin );
     if( p_main->p_memcpy_module == NULL )
     {
@@ -1032,7 +1057,8 @@ static void Version( void )
     ShowConsole();
 #endif
 
-    intf_Msg( VERSION_MESSAGE
+    intf_Msg( VERSION_MESSAGE );
+    intf_Msg(
         "This program comes with NO WARRANTY, to the extent permitted by "
         "law.\nYou may redistribute it under the terms of the GNU General "
         "Public License;\nsee the file named COPYING for details.\n"
@@ -1116,12 +1142,14 @@ static void IllegalSignalHandler( int i_signal )
     sigrelse( i_signal );
 #endif
 
+#if defined( __i386__ )
     fprintf( stderr, "warning: your CPU has %s instructions, but not your "
                      "operating system.\n", psz_capability );
     fprintf( stderr, "         some optimizations will be disabled unless "
                      "you upgrade your OS\n" );
-#ifdef SYS_LINUX
-    fprintf( stderr, "         (for instance Linux kernel 2.4.x or later)" );
+#   if defined( SYS_LINUX )
+    fprintf( stderr, "         (for instance Linux kernel 2.4.x or later)\n" );
+#   endif
 #endif
 
     longjmp( env, 1 );
