@@ -2,7 +2,7 @@
  * beos_init.cpp: Initialization for BeOS specific features 
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: beos_specific.cpp,v 1.12 2001/11/28 15:08:06 massiot Exp $
+ * $Id: beos_specific.cpp,v 1.17 2002/02/08 15:57:29 sam Exp $
  *
  * Authors: Jean-Marc Dressler <polux@via.ecp.fr>
  *
@@ -20,8 +20,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
-#include "defs.h"
-
 #include <Application.h>
 #include <Roster.h>
 #include <Path.h>
@@ -32,13 +30,8 @@
 
 extern "C"
 {
-#include "config.h"
-#include "common.h"
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
+#include <videolan/vlc.h>
 }
-#include "beos_specific.h"
 
 /*****************************************************************************
  * The VlcApplication class
@@ -148,9 +141,11 @@ VlcApplication::~VlcApplication( )
  *****************************************************************************/
 void VlcApplication::AboutRequested( )
 {
-	BAlert *alert;
-	alert = new BAlert( VOUT_TITLE, "BeOS " VOUT_TITLE "\n\n<www.videolan.org>", "Ok" );
-	alert->Go( NULL );
+    BAlert *alert;
+    alert = new BAlert( VOUT_TITLE,
+                        "BeOS " VOUT_TITLE "\n\n<www.videolan.org>",
+                        "Ok" );
+    alert->Go( NULL );
 }
 
 /*****************************************************************************
